@@ -19,6 +19,9 @@ def polish_pattern(pattern, min_frac, min_num, track_set, flank, window_size, bg
 		track_set=track_set, left_flank_to_add=flank,
 		right_flank_to_add=flank)
 
+	if pattern is None:
+		return None
+
 	# Trim by IC
 	ppm = pattern.sequence
 	per_pos_ic = util.compute_per_position_ic(
@@ -59,7 +62,7 @@ def _expand_seqlets_to_fill_pattern(pattern, track_set, left_flank_to_add,
 			new_seqlets.append(seqlet)
 
 	if len(new_seqlets) > 0:
-		return core.AggregatedSeqlet(seqlets=new_seqlets)
+		return core.SeqletSet(seqlets=new_seqlets)
 	else:
 		return None
 
@@ -227,7 +230,7 @@ def SimilarPatternsCollapser(patterns, track_set,
 			if len(pattern.seqlets) > max_seqlets_subsample:
 				subsample = np.random.RandomState(1234).choice(
 					a=pattern.seqlets, replace=False, size=max_seqlets_subsample)
-				pattern = core.AggregatedSeqlet(seqlets=subsample)
+				pattern = core.SeqletSet(seqlets=subsample)
 
 			subsample_patterns.append(pattern)
 
@@ -382,13 +385,14 @@ def SimilarPatternsCollapser(patterns, track_set,
 					min_num=min_num, track_set=track_set, flank=flank_to_add, 
 					window_size=window_size, bg_freq=bg_freq)
 
-				for k in range(len(patterns)):
-					#Replace EVERY case where the parent or child
-					# pattern is present with the new pattern. This
-					# effectively does single-linkage.
-					if (patterns[k]==parent_pattern or
-						patterns[k]==child_pattern):
-						patterns[k]=new_pattern
+				if new_pattern is not None:
+					for k in range(len(patterns)):
+						#Replace EVERY case where the parent or child
+						# pattern is present with the new pattern. This
+						# effectively does single-linkage.
+						if (patterns[k]==parent_pattern or
+							patterns[k]==child_pattern):
+							patterns[k]=new_pattern
 
 		merge_occurred_last_iteration = (len(indices_to_merge) > 0)
 
